==> kvlibsdk_5_23_482.tar.gz: kvlibsdk/kvlclib/KvaLogReader.h <==
/*
**             Copyright 2017 by Kvaser AB, Molndal, Sweden
**                         http://www.kvaser.com
**
** This software is dual licensed under the following two licenses:
** BSD-new and GPLv2. You may use either one. See the included
** COPYING file for details.
**
** License: BSD-new
** ==============================================================================
** Redistribution and use in source and binary forms, with or without
** modification, are permitted provided that the following conditions are met:
**     * Redistributions of source code must retain the above copyright
**       notice, this list of conditions and the following disclaimer.
**     * Redistributions in binary form must reproduce the above copyright
**       notice, this list of conditions and the following disclaimer in the
**       documentation and/or other materials provided with the distribution.
**     * Neither the name of the <organization> nor the
**       names of its contributors may be used to endorse or promote products
**       derived from this software without specific prior written permission.
**
** THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
** AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
** IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
** ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE
** LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
** CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
** SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR
** BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER
** IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
** ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
** POSSIBILITY OF SUCH DAMAGE.
**
**
** License: GPLv2
** ==============================================================================
** This program is free software; you can redistribute it and/or modify
** it under the terms of the GNU General Public License as published by
** the Free Software Foundation; either version 2 of the License, or
** (at your option) any later version.
**
** This program is distributed in the hope that it will be useful,
** but WITHOUT ANY WARRANTY; without even the implied warranty of
** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
** GNU General Public License for more details.
**
** You should have received a copy of the GNU General Public License
** along with this program; if not, write to the Free Software
** Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA
**
**
** IMPORTANT NOTICE:
** ==============================================================================
** This source code is made available for free, as an open license, by Kvaser AB,
** for use with its applications. Kvaser AB does not accept any liability
** whatsoever for any third party patent or other immaterial property rights
** violations that may result from any usage of this source code, regardless of
** the combination of source code and various applications that it can be used
** in, or with.
**
** -----------------------------------------------------------------------------
*/

#ifndef KVALOGREADER_H_
#define KVALOGREADER_H_

#include <stdint.h>

#include <stdio.h>
#include "KvaConverterMisc.h"


class KvaLogReader {
  protected:
    FILE *infile;
    int64_t file_size;
    int64_t file_position;
    int64_t get_file_size(const char *filename);
    KvlcStatus read_file(char *string, size_t num);
    KvlcStatus read_line(char *string, int num);
    time_uint64 start_of_measurement64;
    time_uint64 last_clock_event;
    time_uint64 first_timestamp;
    bool isOpened;
    bool time_gap;

  public:
    KvaLogReader();
    virtual ~KvaLogReader();
    // Reads an event from a file, interprets it and places info in logEvent
    virtual KvlcStatus read_row(imLogData *logEvent) = 0;
    virtual unsigned long event_count() = 0;
    virtual bool isBinary() = 0;
    KvlcStatus open_file(const char *filename);
    KvlcStatus close_file();
    // Interpret event is like read_row but gets its input from the caller.
    virtual KvlcStatus interpret_event(void* /* event */, imLogData* /* logEvent */)
    { PRINTF(("default implementation of interpret_event\n")); return kvlcERR_NOT_IMPLEMENTED; }
    virtual KvlcStatus next_file();
    virtual KvlcStatus verify_signals() {return kvlcERR_NOT_IMPLEMENTED;}
};

#include "KvaReaderMaker.h"

#endif /*KVALOGREADER_H_*/

==> kvlibsdk_5_26_679.tar.gz: kvlibsdk/kvlclib/KvaLogReader.h <==
/*
**             Copyright 2017 by Kvaser AB, Molndal, Sweden
**                         http://www.kvaser.com
**
** This software is dual licensed under the following two licenses:
** BSD-new and GPLv2. You may use either one. See the included
** COPYING file for details.
**
** License: BSD-new
** ==============================================================================
** Redistribution and use in source and binary forms, with or without
** modification, are permitted provided that the following conditions are met:
**     * Redistributions of source code must retain the above copyright
**       notice, this list of conditions and the following disclaimer.
**     * Redistributions in binary form must reproduce the above copyright
**       notice, this list of conditions and the following disclaimer in the
**       documentation and/or other materials provided with the distribution.
**     * Neither the name of the <organization> nor the
**       names of its contributors may be used to endorse or promote products
**       derived from this software without specific prior written permission.
**
** THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
** AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
** IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
** ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE
** LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
** CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
** SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR
** BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER
** IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
** ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
** POSSIBILITY OF SUCH DAMAGE.
**
**
** License: GPLv2
** ==============================================================================
** This program is free software; you can redistribute it and/or modify
** it under the terms of the GNU General Public License as published by
** the Free Software Foundation; either version 2 of the License, or
** (at your option) any later version.
**
** This program is distributed in the hope that it will be useful,
** but WITHOUT ANY WARRANTY; without even the implied warranty of
** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
** GNU General Public License for more details.
**
** You should have received a copy of the GNU General Public License
** along with this program; if not, write to the Free Software
** Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA
**
**
** IMPORTANT NOTICE:
** ==============================================================================
** This source code is made available for free, as an open license, by Kvaser AB,
** for use with its applications. Kvaser AB does not accept any liability
** whatsoever for any third party patent or other immaterial property rights
** violations that may result from any usage of this source code, regardless of
** the combination of source code and various applications that it can be used
** in, or with.
**
** -----------------------------------------------------------------------------
*/

#ifndef KVALOGREADER_H_
#define KVALOGREADER_H_

#include <stdint.h>

#include <stdio.h>
#include "KvaConverterMisc.h"


class KvaLogReader {
  protected:
    FILE *infile;
    int64_t file_size;
    int64_t file_position;
    int64_t get_file_size(const char *filename);
    KvlcStatus read_file(char *string, size_t num);
    KvlcStatus read_line(char *string, int num);
    time_uint64 start_of_measurement64;
    time_uint64 last_clock_event;
    time_uint64 first_timestamp;
    bool isOpened;

  public:
    KvaLogReader();
    virtual ~KvaLogReader();
    // Reads an event from a file, interprets it and places info in logEvent
    virtual KvlcStatus read_row(imLogData *logEvent) = 0;
    virtual unsigned long event_count() = 0;
    virtual bool isBinary() = 0;
    virtual KvlcStatus open_file(const char *filename);
    virtual KvlcStatus close_file();
    // Interpret event is like read_row but gets its input from the caller.
    virtual KvlcStatus interpret_event(void* /* event */, imLogData* /* logEvent */)
    { PRINTF(("default implementation of interpret_event\n")); return kvlcERR_NOT_IMPLEMENTED; }
    virtual KvlcStatus next_file();
    virtual KvlcStatus verify_signals() {return kvlcERR_NOT_IMPLEMENTED;}
};

#include "KvaReaderMaker.h"

#endif /*KVALOGREADER_H_*/
